@@ -1,9 +1,9 @@
 package Color::RGB::Util;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-03-12'; # DATE
+our $DATE = '2021-08-06'; # DATE
 our $DIST = 'Color-RGB-Util'; # DIST
-our $VERSION = '0.605'; # VERSION
+our $VERSION = '0.606'; # VERSION
 
 use 5.010001;
 use strict;
@@ -206,15 +206,22 @@ sub reverse_rgb_color {
 }
 
 sub rgb2grayscale {
-    my ($rgb) = @_;
+    my ($rgb, $algo) = @_;
 
     my ($r, $g, $b) =
         $rgb =~ $re_rgb or die "Invalid rgb color '$rgb', must be in 'ffffff' form";
     for ($r, $g, $b) { $_ = hex $_ }
 
-    # basically we just average the R, G, B
-    my $avg = int(($r + $g + $b)/3);
-    return sprintf("%02x%02x%02x", $avg, $avg, $avg);
+    $algo //= 'average';
+    if ($algo eq 'weighted_average') {
+        my $avg = int(0.299*$r + 0.587*$g + 0.114*$b);
+        return sprintf("%02x%02x%02x", $avg, $avg, $avg);
+    } elsif ($algo eq 'average') {
+        my $avg = int(($r + $g + $b)/3);
+        return sprintf("%02x%02x%02x", $avg, $avg, $avg);
+    } else {
+        die "Unknown algo '$algo'";
+    }
 }
 
 sub rgb2int {
@@ -282,8 +289,10 @@ sub rgb_diff {
         } else { # hsv_euclidean
             return ($dh2 + $ds2 + $dv2)**0.5;
         }
-    } else { # euclidean
+    } elsif ($algo eq 'euclidean') {
         return ($dr2 + $dg2 + $db2)**0.5;
+    } else {
+        die "Unknown algo '$algo'";
     }
 }
 
@@ -525,7 +534,7 @@ Color::RGB::Util - Utilities related to RGB colors
 
 =head1 VERSION
 
-This document describes version 0.605 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2021-03-12.
+This document describes version 0.606 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2021-08-06.
 
 =head1 SYNOPSIS
 
@@ -572,7 +581,8 @@ This document describes version 0.605 of Color::RGB::Util (from Perl distributio
 
  say reverse_rgb_color('0033CC');                # => ffcc33
 
- say rgb2grayscale('0033CC');                    # => 555555
+ say rgb2grayscale('0033CC');                     # => 555555 # default 'average' algo
+ say rgb2grayscale('0033CC', 'weighted_average'); # => 353535
 
  say rgb2int("ffffff");                          # 16777215 (which is 0xffffff)
 
@@ -773,9 +783,31 @@ Reverse C<$rgb>.
 
 Usage:
 
- my $rgb_gs = rgb2grayscale($rgb);
+ my $rgb_gs = rgb2grayscale($rgb [ , $algo ]);
 
-Convert C<$rgb> to grayscale RGB value.
+Convert C<$rgb> to grayscale RGB value. There are several algorithms (C<$algo>)
+to choose from:
+
+=over
+
+=item * average
+
+The Average method takes the average value of R, G, and B as the grayscale
+value.
+
+ Grayscale = (R + G + B ) / 3.
+
+The average method is simple but does not take into account the non-linearity of
+human vision (eyes are most sensitive to green, less to red, least to blue).
+
+=item * weighted_average
+
+This method gives weights to each of red, green, blue elements to take into
+account the sensitivity of human eyes.
+
+ Grayscale  = 0.299R + 0.587G + 0.114B
+
+=back
 
 See also L<rgb2sepia>.
 
@@ -946,11 +978,11 @@ Please visit the project's homepage at L<https://metacpan.org/release/Color-RGB-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Color-RGB-Util>.
+Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Color-Util>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Color-RGB-Util/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Color-RGB-Util>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -964,6 +996,22 @@ L<Color::ANSI::Util>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords ryosh2 (on pc-office) Steven Haryanto
+
+=over 4
+
+=item *
+
+ryosh2 (on pc-office) <ryosharyanto@gmail.com>
+
+=item *
+
+Steven Haryanto <sharyanto@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2021, 2020, 2019, 2018, 2015, 2014, 2013 by perlancar@cpan.org.
